@@ -11,7 +11,7 @@ var completionOptions = cobra.CompletionOptions{DisableDefaultCmd: true}
 // MacpineCmd represents the base command when called without any subcommands
 var MacpineCmd = &cobra.Command{
 	Use:               "alpine",
-	Short:             "Create, control and connect to Alpine instances.",
+	Short:             "Create, control, and connect to Alpine instances.",
 	Long:              ``,
 	CompletionOptions: completionOptions,
 }
@@ -30,12 +30,16 @@ func init() {
 	MacpineCmd.AddCommand(launchCmd)
 	MacpineCmd.AddCommand(stopCmd)
 	MacpineCmd.AddCommand(startCmd)
+	MacpineCmd.AddCommand(restartCmd)
+	MacpineCmd.AddCommand(pauseCmd)
+	MacpineCmd.AddCommand(resumeCmd)
 	MacpineCmd.AddCommand(deleteCmd)
 	MacpineCmd.AddCommand(listCmd)
 	MacpineCmd.AddCommand(publishCmd)
 	MacpineCmd.AddCommand(importCmd)
 	MacpineCmd.AddCommand(execCmd)
 	MacpineCmd.AddCommand(editCmd)
+	MacpineCmd.AddCommand(renameCmd)
 	MacpineCmd.AddCommand(shellCmd)
 	MacpineCmd.AddCommand(completionCmd)
 	MacpineCmd.AddCommand(tagCmd)
