@@ -6,5 +6,7 @@ import (
 
 // Exec executes a command inside VM
 func Exec(config qemu.MachineConfig, cmd string) error {
-	return config.Exec(cmd, false) // false: run as default ssh user, not (necessarily) root
+
+	_, err := config.Exec(cmd, false)
+	return err // false: run as default ssh user, not (necessarily) root
 }
